Struct finality_grandpa::CatchUp [−][src]
pub struct CatchUp<H, N, S, Id> {
pub round_number: u64,
pub prevotes: Vec<SignedPrevote<H, N, S, Id>>,
pub precommits: Vec<SignedPrecommit<H, N, S, Id>>,
pub base_hash: H,
pub base_number: N,
}Expand description
A catch-up message, which is an aggregate of prevotes and precommits necessary to complete a round.
This message contains a “base”, which is a block all of the vote-targets are a descendent of.
Fields
round_number: u64Round number.
prevotes: Vec<SignedPrevote<H, N, S, Id>>Prevotes for target block or any block after it that justify this catch-up.
precommits: Vec<SignedPrecommit<H, N, S, Id>>Precommits for target block or any block after it that justify this catch-up.
base_hash: HThe base hash. See struct docs.
base_number: NThe base number. See struct docs.